@@ -209,7 +209,9 @@ sub new {
           if ($c->{type} eq 'mandatory') {
             # field
             foreach my $f ($c->{field}->@*) {
-              push $self->{entrytypesbyname}{$es}{constraints}{mandatory}->@*, $f->{content};
+              if (not first {$f->{content} eq $_} $self->{entrytypesbyname}{$es}{constraints}{mandatory}->@*) {
+                push $self->{entrytypesbyname}{$es}{constraints}{mandatory}->@*, $f->{content};
+              }
             }
             # xor set of fields
             # [ XOR, field1, field2, ... , fieldn ]
@@ -721,7 +723,7 @@ sub field_is_skipout {
 =head2 check_mandatory_constraints
 
     Checks constraints of type "mandatory" on entry and
-    returns an arry of warnings, if any
+    returns an array of warnings, if any
 
 =cut
 
@@ -786,7 +788,7 @@ sub check_mandatory_constraints {
 =head2 check_conditional_constraints
 
     Checks constraints of type "conditional" on entry and
-    returns an arry of warnings, if any
+    returns an array of warnings, if any
 
 =cut
 
@@ -2021,7 +2023,7 @@ L<https://github.com/plk/biber/issues>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2024 Philip Kime, all rights reserved.
+Copyright 2012-2025 Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
