@@ -827,6 +827,8 @@ sub create_entry {
       $logger->debug("Creating entry with key '$k'");
     }
 
+    $bibentry->set_field('entrytype', $e->getAttribute('entrytype'));
+
     # We put all the fields we find modulo field aliases into the object.
     # Validation happens later and is not datasource dependent
     foreach my $f (uniq map { if (_norm($_->nodeName) eq 'names') { $_->getAttribute('type') }
@@ -847,7 +849,6 @@ sub create_entry {
       }
     }
 
-    $bibentry->set_field('entrytype', $e->getAttribute('entrytype'));
     $bibentry->set_field('datatype', 'biblatexml');
     $bibentries->add_entry($k, $bibentry);
   }
@@ -918,7 +919,7 @@ sub _literal {
   }
 
   # eprint is special case
-  if ($f eq "$NS:eprint") {
+  if (fc(_norm($f) eq "$NS:eprint")) {
     $bibentry->set_datafield('eprinttype', $node->getAttribute('type'));
     if (my $ec = $node->getAttribute('class')) {
       $bibentry->set_datafield('eprintclass', $ec);
@@ -1025,6 +1026,7 @@ sub _datetime {
   my $secnum = $Biber::MASTER->get_current_section;
   my $section = $Biber::MASTER->sections->get_section($secnum);
   my $ds = $section->get_keytods($key);
+  my $bee = $bibentry->get_field('entrytype');
 
   foreach my $node ($entry->findnodes("./$f")) {
 
@@ -1049,7 +1051,7 @@ sub _datetime {
         # Save uncertain date information
         $bibentry->set_field($datetype . 'dateuncertain', 1) if $CONFIG_DATE_PARSERS{start}->uncertain;
 
-        # Date had EDTF 5.2.2 unspecified format
+        # Date had ISO8601-2 unspecified format
         # This does not differ for *enddate components as these are split into ranges
         # from non-ranges only
         if ($unspec) {
@@ -1084,7 +1086,7 @@ sub _datetime {
         }
       }
       else {
-        biber_warn("Datamodel: Entry '$key' ($ds): Invalid format '" . $start->get_node(1)->textContent() . "' of date field '$f' range start - ignoring", $bibentry);
+        biber_warn("Datamodel: $bee entry '$key' ($ds): Invalid format '" . $start->get_node(1)->textContent() . "' of date field '$f' range start - ignoring", $bibentry);
       }
 
       # End of range
@@ -1133,7 +1135,7 @@ sub _datetime {
         }
       }
       else {
-        biber_warn("Entry '$key' ($ds): Invalid format '" . $end->get_node(1)->textContent() . "' of date field '$f' range end - ignoring", $bibentry);
+        biber_warn("$bee entry '$key' ($ds): Invalid format '" . $end->get_node(1)->textContent() . "' of date field '$f' range end - ignoring", $bibentry);
       }
     }
     else { # Simple date
@@ -1150,7 +1152,7 @@ sub _datetime {
         # Save uncertain date information
         $bibentry->set_field($datetype . 'dateuncertain', 1) if $CONFIG_DATE_PARSERS{start}->uncertain;
 
-        # Date had EDTF 5.2.2 unspecified format
+        # Date had ISO8601-2 unspecified format
         # This does not differ for *enddate components as these are split into ranges
         # from non-ranges only
         if ($unspec) {
@@ -1185,7 +1187,7 @@ sub _datetime {
         }
       }
       else {
-        biber_warn("Entry '$key' ($ds): Invalid format '" . $node->textContent() . "' of date field '$f' - ignoring", $bibentry);
+        biber_warn("$bee entry '$key' ($ds): Invalid format '" . $node->textContent() . "' of date field '$f' - ignoring", $bibentry);
       }
     }
   }
@@ -1260,6 +1262,7 @@ sub _name {
       nameinitstring    => 'Doe_JF',
       gender            => sm,
       useprefix         => 1,
+      hashid            => 'someid',
       sortingnamekeytemplatename => 'templatename'
     }
 
@@ -1311,19 +1314,20 @@ sub parsename {
     }
   }
 
-  my %nameparts;
+  my %nameinfo;
   foreach my $np ($dm->get_constant_value('nameparts')) { # list type so returns list
-    $nameparts{$np} = {string  => $namec{$np} // undef,
+    $nameinfo{$np} = {string  => $namec{$np} // undef,
                        initial => exists($namec{$np}) ? $namec{"${np}-i"} : undef};
 
     # Record max namepart lengths
-    $section->set_np_length($np, length($nameparts{$np}{string}))  if $nameparts{$np}{string};
-    $section->set_np_length("${np}-i", length(join('', $nameparts{$np}{initial}->@*))) if $nameparts{$np}{initial};
+    $section->set_np_length($np, length($nameinfo{$np}{string}))  if $nameinfo{$np}{string};
+    $section->set_np_length("${np}-i", length(join('', $nameinfo{$np}{initial}->@*))) if $nameinfo{$np}{initial};
   }
 
   my $newname = Biber::Entry::Name->new(
-                                        %nameparts,
-                                        gender => $node->getAttribute('gender')
+                                        %nameinfo,
+                                        gender => $node->getAttribute('gender'),
+                                        hashid => $node->getAttribute('id')
                                        );
 
   # per-name options
@@ -1434,7 +1438,7 @@ sub _changenode {
     # set attribute value
     if ($n->nodeType == XML_ATTRIBUTE_NODE) {
       if ($nodeval) {
-        $$error = "Tried to replace '$xp_target_s' Atribute node with complex data";
+        $$error = "Tried to replace '$xp_target_s' Attribute node with complex data";
         return 0;
       }
       $n->setValue(NFC($value));
@@ -1576,7 +1580,7 @@ L<https://github.com/plk/biber/issues>.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009-2012 François Charette and Philip Kime, all rights reserved.
-Copyright 2012-2022 Philip Kime, all rights reserved.
+Copyright 2012-2025 Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
